==> apache-dubbo-3.0.0-src.zip: apache-dubbo-3.0.0-src/dubbo-registry/dubbo-registry-api/src/test/java/org/apache/dubbo/registry/RegistryServiceListener1.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.dubbo.registry;

import org.apache.dubbo.common.URL;
import org.apache.dubbo.common.extension.Activate;

@Activate(order = 1)
public class RegistryServiceListener1 implements RegistryServiceListener {
    static RegistryServiceListener delegate;

    @Override
    public void onRegister(URL url, Registry registry) {
        delegate.onRegister(url, registry);
    }

    @Override
    public void onUnregister(URL url, Registry registry) {
        delegate.onUnregister(url, registry);
    }

    @Override
    public void onSubscribe(URL url, Registry registry) {
        delegate.onSubscribe(url, registry);
    }

    @Override
    public void onUnsubscribe(URL url, Registry registry) {
        delegate.onUnsubscribe(url, registry);
    }
}

==> apache-dubbo-3.2.19-src.zip: apache-dubbo-3.2.19-src/dubbo-registry/dubbo-registry-api/src/test/java/org/apache/dubbo/registry/RegistryServiceListener1.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.dubbo.registry;

import org.apache.dubbo.common.URL;
import org.apache.dubbo.common.extension.Activate;

@Activate(order = 1, value = "listener-one")
public class RegistryServiceListener1 implements RegistryServiceListener {
    static RegistryServiceListener delegate;

    @Override
    public void onRegister(URL url, Registry registry) {
        delegate.onRegister(url, registry);
    }

    @Override
    public void onUnregister(URL url, Registry registry) {
        delegate.onUnregister(url, registry);
    }

    @Override
    public void onSubscribe(URL url, Registry registry) {
        delegate.onSubscribe(url, registry);
    }

    @Override
    public void onUnsubscribe(URL url, Registry registry) {
        delegate.onUnsubscribe(url, registry);
    }
}
